What’s new in version 1.1.7
===========================
Version available since September 26th 2022


New Features
------------
- Users can compute the gradients of ODE systems for dynamic optimization.

Changes
-------
- plotResults and plotXY functions display 2 graphes per figure instead of one.
- In odeint45_extract function, partial derivatives of tchoc are computed with implicit functions theorem.


Contributors
------------
Lucas Agobert
